import { ToastContainer, toast } from 'react-toastify'
import 'react-toastify/dist/ReactToastify.css'
import { ToastType } from '../types/toastType'
import { useEffect } from 'react'

export const ToastAlert = ({ type, message, promise, config, limit }: ToastType): JSX.Element => {

  useEffect(() => {
    if (type === 'error') {
      toast.error(message, {
        toastId: message + type
      })
    } else if (type === 'warning') {
      toast.warning(message, {
        toastId: message + type
      })
    } else if (type === 'success') {
      toast.success(message, {
        toastId: message + type
      })
    } else if (type === 'info') {
      toast.info(message, {
        toastId: message + type
      })
    } else if (type === 'promise') {
      if (promise !== undefined && config !== undefined) {
        toast.promise(
          new Promise((resolve, reject) => {
            promise
              .then(() => resolve(0))
              .catch((e: any) => reject(e))
          }),
          config
        )
      }
    }
  }, [type, message, promise, config])

  return (
    <ToastContainer rtl={true}
      role={
        type ?
          type.charAt(0).toUpperCase() + type.slice(1) + 'alert' :
          'Alert'
      }
      position={'top-right'}
      autoClose={5000}
      hideProgressBar={false}
      closeOnClick={true}
      pauseOnHover={false}
      draggable={false}
      pauseOnFocusLoss={false}
      theme={'colored'}
      limit={limit} />
  )
}
